@@ -63,7 +63,7 @@
 	(error "~s isn't a known field accessor" name)))
     increment))
 
-(eval-when (eval compile load)
+(eval-when (:execute :compile-toplevel :load-toplevel)
 (defun getify (name)
   (xintern name '-get))
 
@@ -90,7 +90,7 @@
 	 ,@(cdr get-macro))
        (defmacro ,(putify name) ,(car put-macro)
 	 ,@(cdr put-macro))
-       ,@(when *type-check?*
+       ,@(when +type-check?+
 	   (let ((predicating-put (third get-put-macros)))
 	     (when predicating-put
 	       `((setf (get ',name 'predicating-put) t)
@@ -217,18 +217,17 @@
   ((index &rest keywords)
    (let ((value (gensym)))
      `(let ((,value (read-card8 ,index)))
-	(and (< ,value ,(length keywords))
-	     (svref ',(apply #'vector keywords) ,value)))))
+	(declare (type (integer 0 (,(length keywords))) ,value))
+	(type-check ,value '(integer 0 (,(length keywords))))
+	(svref ',(apply #'vector keywords) ,value))))
   ((index thing &rest keywords)
    `(write-card8 ,index (position ,thing
-				  #+lispm ',keywords ;; Lispm's prefer lists
-				  #-lispm (the simple-vector ',(apply #'vector keywords))
+				  (the simple-vector ',(apply #'vector keywords))
 				  :test #'eq)))
   ((index thing &rest keywords)
    (let ((value (gensym)))
      `(let ((,value (position ,thing
-			      #+lispm ',keywords
-			      #-lispm (the simple-vector ',(apply #'vector keywords))
+			      (the simple-vector ',(apply #'vector keywords))
 			      :test #'eq)))
 	(and ,value (write-card8 ,index ,value))))))
 
@@ -236,18 +235,17 @@
   ((index &rest keywords)
    (let ((value (gensym)))
      `(let ((,value (read-card16 ,index)))
-	(and (< ,value ,(length keywords))
-	     (svref ',(apply #'vector keywords) ,value)))))
+	(declare (type (integer 0 (,(length keywords))) ,value))
+	(type-check ,value '(integer 0 (,(length keywords))))
+	(svref ',(apply #'vector keywords) ,value))))
   ((index thing &rest keywords)
    `(write-card16 ,index (position ,thing
-				   #+lispm ',keywords ;; Lispm's prefer lists
-				   #-lispm (the simple-vector ',(apply #'vector keywords))
+				   (the simple-vector ',(apply #'vector keywords))
 				   :test #'eq)))
   ((index thing &rest keywords)
    (let ((value (gensym)))
      `(let ((,value (position ,thing
-			      #+lispm ',keywords
-			      #-lispm (the simple-vector ',(apply #'vector keywords))
+			      (the simple-vector ',(apply #'vector keywords))
 			      :test #'eq)))
 	(and ,value (write-card16 ,index ,value))))))
 
@@ -255,22 +253,21 @@
   ((index &rest keywords)
    (let ((value (gensym)))
      `(let ((,value (read-card29 ,index)))
-	(and (< ,value ,(length keywords))
-	     (svref ',(apply #'vector keywords) ,value)))))
+	(declare (type (integer 0 (,(length keywords))) ,value))
+	(type-check ,value '(integer 0 (,(length keywords))))
+	(svref ',(apply #'vector keywords) ,value))))
   ((index thing &rest keywords)
    `(write-card29 ,index (position ,thing
-				   #+lispm ',keywords ;; Lispm's prefer lists
-				   #-lispm (the simple-vector ',(apply #'vector keywords))
+				   (the simple-vector ',(apply #'vector keywords))
 				   :test #'eq)))
   ((index thing &rest keywords)
    (if (cdr keywords) ;; IF more than one
        (let ((value (gensym)))
 	 `(let ((,value (position ,thing
-				   #+lispm ',keywords
-				   #-lispm (the simple-vector ',(apply #'vector keywords))
+				  (the simple-vector ',(apply #'vector keywords))
 				  :test #'eq)))
 	    (and ,value (write-card29 ,index ,value))))
-     `(and (eq ,thing ,(car keywords)) (write-card29 ,index 0)))))
+       `(and (eq ,thing ,(car keywords)) (write-card29 ,index 0)))))
 
 (deftype member-vector (vector) `(member ,@(coerce (symbol-value vector) 'list)))
 
@@ -303,8 +300,9 @@
   ((index)
    (let ((value (gensym)))
      `(let ((,value (read-card29 ,index)))
-	(and (< ,value ,(length *boole-vector*))
-	     (svref *boole-vector* ,value)))))
+	(declare (type (integer 0 (,(length *boole-vector*))) ,value))
+	(type-check ,value '(integer 0 (,(length *boole-vector*))))
+	(svref *boole-vector* ,value))))
   ((index thing)
    `(write-card29 ,index (position ,thing (the simple-vector *boole-vector*))))
   ((index thing)
@@ -333,7 +331,7 @@
    `(read-bitvector256 buffer-bbuf ,real-index ,data))
   ((index map &optional (real-index index) (buffer '%buffer))
    `(write-bitvector256 ,buffer (index+ buffer-boffset ,real-index) ,map)))
-   
+
 (define-accessor string (nil)
   ((length index &key reply-buffer)
    `(read-sequence-char
@@ -390,16 +388,17 @@
   '(let* ((format (read-card8 1))
  	  (sequence (make-array (ceiling 160 format)
 				:element-type `(unsigned-byte ,format))))
+     (declare (type (member 8 16 32) format))
      (do ((i 12)
-	  (j 0 (1+ j)))
+	  (j 0 (index1+ j)))
 	 ((>= i 32))
        (case format
 	 (8 (setf (aref sequence j) (read-card8 i))
-	    (incf i))
+	    (index-incf i))
 	 (16 (setf (aref sequence j) (read-card16 i))
-	     (incf i 2))
+	     (index-incf i 2))
 	 (32 (setf (aref sequence j) (read-card32 i))
-	     (incf i 4))))
+	     (index-incf i 4))))
      sequence))
 
 (defmacro client-message-event-put-sequence (format sequence)
@@ -470,7 +469,7 @@
 (defmacro or-expand (&rest forms &environment environment)
   `(cond ,@(mapcar #'(lambda (forms)
 		       (mapcar #'(lambda (form)
-				   (macroexpand form environment))
+				   (clx-macroexpand form environment))
 			       forms))
 		   forms)))
 
@@ -487,7 +486,7 @@
 	`(let ((,value (read-card32 ,index)))
 	   (macrolet ((read-card32 (index) index ',value)
 		      (read-card29 (index) index ',value))
-	     ,(macroexpand `(or-expand ,@(nreverse result)) environment))))
+	     ,(clx-macroexpand `(or-expand ,@(nreverse result)) environment))))
      (let ((item (car types))
 	   (args nil))
        (when (consp item)
@@ -504,7 +503,7 @@
 	(result))
        ((endp types)
 	`(cond ,@(nreverse result)
-	       ,@(when *type-check?*
+	       ,@(when +type-check?+
 		   `((t (x-type-error ,value '(or ,@type-list)))))))
      (let* ((type (car types))
 	    (type-name type)
@@ -514,7 +513,7 @@
 	       type-name (car type)))
        (push
 	 `(,@(cond ((get type-name 'predicating-put) nil)
-		   ((or *type-check?* (cdr types)) `((type? ,value ',type)))
+		   ((or +type-check?+ (cdr types)) `((type? ,value ',type)))
 		   (t '(t)))
 	   (,(putify type-name (get type-name 'predicating-put)) ,index ,value ,@args))
 	 result)))))
@@ -529,10 +528,7 @@
 
 (defun mask-get (index type-values body-function)
   (declare (type function body-function)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent body-function)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg body-function))
+	   (dynamic-extent body-function))
   ;; This is a function, because it must return more than one form (called by get-put-items)
   ;; Functions that use this must have a binding for %MASK
   (let* ((bit 0)
@@ -559,21 +555,18 @@
 	     ,(car result))
       ,@(cdr result))))
 
-;; MASK-PUT 
+;; MASK-PUT
 
 (defun mask-put (index type-values body-function)
   (declare (type function body-function)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent body-function)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg body-function))
+	   (dynamic-extent body-function))
   ;; The MASK type writes a 32 bit mask with 1 bits for each non-nil value in TYPE-VALUES
   ;; A 32 bit value follows for each non-nil value.
   `((let ((%mask 0)
 	  (%index ,index))
       ,@(let ((bit 1))
 	  (get-put-items
-	    index type-values t 
+	    index type-values t
 	    #'(lambda (type index item args)
 		(declare (ignore index))
 		(if (or (symbolp item) (constantp item))
@@ -602,7 +595,7 @@
 ;
 (defmacro type-check (value type)
   value type
-  (when *type-check?*
+  (when +type-check?+
     `(unless (type? ,value ,type)
        (x-type-error ,value ,type))))
 
@@ -627,10 +620,7 @@
 
 (defun get-put-items (index type-args putp &optional body-function)
   (declare (type (or null function) body-function)
-	   #+clx-ansi-common-lisp
-	   (dynamic-extent body-function)
-	   #+(and lispm (not clx-ansi-common-lisp))
-	   (sys:downward-funarg body-function))
+	   (dynamic-extent body-function))
   ;; Given a lists of the form (type item item ... item)
   ;; Calls body-function with four arguments, a function name,
   ;; index, item name, and optional arguments.
@@ -666,9 +656,9 @@
 		     (append result (funcall body-function type index (car item) args)))
 	       (when (constantp index)
 		 ;; Variable length requests have null length increment.
-		 ;; Variable length requests set the request size 
+		 ;; Variable length requests set the request size
 		 ;; & maintain buffer pointers
-		 (if (null increment) 
+		 (if (null increment)
 		     (setq index nil)
 		   (progn
 		     (incf index increment)
@@ -680,7 +670,7 @@
 	   &body type-args)
   (multiple-value-bind (code index item-sizes)
       (get-put-items 4 type-args t)
-    (let ((length (if length `(index+ ,length *requestsize*) '*requestsize*))
+    (let ((length (if length `(index+ ,length +requestsize+) '+requestsize+))
 	  (sizes (remove-duplicates (append '(8 16) item-sizes sizes))))
       `(with-buffer-output (,buffer :length ,length :sizes ,sizes)
 	 (setf (buffer-last-request ,buffer) buffer-boffset)
@@ -700,7 +690,6 @@
 		(declare (type display .display.))
 		(with-buffer-request-internal (.display. ,opcode ,@options)
 		  ,@type-args)))
-	 #+clx-ansi-common-lisp
 	 (declare (dynamic-extent #'.request-body.))
 	 (,(if (eq (car (macroexpand '(with-buffer (buffer)) env)) 'progn)
 	       'with-buffer-request-function-nolock
@@ -711,7 +700,7 @@
        (with-buffer (.display.)
 	 ,@(when gc-force `((force-gcontext-changes-internal ,gc-force)))
 	 (multiple-value-prog1
-	   (without-aborts 
+	   (without-aborts
 	     (with-buffer-request-internal (.display. ,opcode ,@options)
 	       ,@type-args))
 	   (display-invoke-after-function .display.))))))
@@ -740,7 +729,6 @@
 			   (type reply-buffer .reply-buffer.))
 		  (progn .display. .reply-buffer. nil)
 		  ,reply-body))
-	   #+clx-ansi-common-lisp
 	   (declare (dynamic-extent #'.request-body. #'.reply-body.))
 	   (with-buffer-request-and-reply-function
 	     ,buffer ,multiple-reply #'.request-body. #'.reply-body.))
@@ -751,7 +739,7 @@
 		  (type (or null pending-command) .pending-command.)
 		  (type (or null reply-buffer) .reply-buffer.))
 	 (unwind-protect
-	     (progn 
+	     (progn
 	       (with-buffer (.display.)
 		 (setq .pending-command. (start-pending-command .display.))
 		 (without-aborts
@@ -824,128 +812,128 @@
 
 ;;;
 ;;; Request codes
-;;; 
+;;;
 
-(defconstant *x-createwindow*                  1)
-(defconstant *x-changewindowattributes*        2)
-(defconstant *x-getwindowattributes*           3)
-(defconstant *x-destroywindow*                 4)
-(defconstant *x-destroysubwindows*             5)  
-(defconstant *x-changesaveset*                 6)
-(defconstant *x-reparentwindow*                7)
-(defconstant *x-mapwindow*                     8)
-(defconstant *x-mapsubwindows*                 9)
-(defconstant *x-unmapwindow*                  10)
-(defconstant *x-unmapsubwindows*              11) 
-(defconstant *x-configurewindow*              12)
-(defconstant *x-circulatewindow*              13)
-(defconstant *x-getgeometry*                  14)
-(defconstant *x-querytree*                    15)
-(defconstant *x-internatom*                   16)
-(defconstant *x-getatomname*                  17)
-(defconstant *x-changeproperty*               18)
-(defconstant *x-deleteproperty*               19)
-(defconstant *x-getproperty*                  20)
-(defconstant *x-listproperties*               21)
-(defconstant *x-setselectionowner*            22)  
-(defconstant *x-getselectionowner*            23) 
-(defconstant *x-convertselection*             24)
-(defconstant *x-sendevent*                    25)
-(defconstant *x-grabpointer*                  26)
-(defconstant *x-ungrabpointer*                27)
-(defconstant *x-grabbutton*                   28)
-(defconstant *x-ungrabbutton*                 29)
-(defconstant *x-changeactivepointergrab*      30)         
-(defconstant *x-grabkeyboard*                 31)
-(defconstant *x-ungrabkeyboard*               32)
-(defconstant *x-grabkey*                      33)
-(defconstant *x-ungrabkey*                    34)
-(defconstant *x-allowevents*                  35)
-(defconstant *x-grabserver*                   36)     
-(defconstant *x-ungrabserver*                 37)       
-(defconstant *x-querypointer*                 38)       
-(defconstant *x-getmotionevents*              39)          
-(defconstant *x-translatecoords*              40)               
-(defconstant *x-warppointer*                  41)      
-(defconstant *x-setinputfocus*                42)        
-(defconstant *x-getinputfocus*                43)        
-(defconstant *x-querykeymap*                  44)      
-(defconstant *x-openfont*                     45)   
-(defconstant *x-closefont*                    46)    
-(defconstant *x-queryfont*                    47)
-(defconstant *x-querytextextents*             48)    
-(defconstant *x-listfonts*                    49) 
-(defconstant *x-listfontswithinfo*    	      50)
-(defconstant *x-setfontpath*                  51)
-(defconstant *x-getfontpath*                  52)
-(defconstant *x-createpixmap*                 53)      
-(defconstant *x-freepixmap*                   54)   
-(defconstant *x-creategc*                     55)
-(defconstant *x-changegc*                     56)
-(defconstant *x-copygc*                       57)
-(defconstant *x-setdashes*                    58)  
-(defconstant *x-setcliprectangles*            59)         
-(defconstant *x-freegc*                       60)
-(defconstant *x-cleartobackground*            61)          
-(defconstant *x-copyarea*                     62)
-(defconstant *x-copyplane*                    63)
-(defconstant *x-polypoint*                    64)
-(defconstant *x-polyline*                     65)
-(defconstant *x-polysegment*                  66)  
-(defconstant *x-polyrectangle*                67)   
-(defconstant *x-polyarc*                      68)
-(defconstant *x-fillpoly*                     69)
-(defconstant *x-polyfillrectangle*            70)        
-(defconstant *x-polyfillarc*                  71) 
-(defconstant *x-putimage*                     72)
-(defconstant *x-getimage*                     73)
-(defconstant *x-polytext8*                    74)   
-(defconstant *x-polytext16*                   75)   
-(defconstant *x-imagetext8*                   76)  
-(defconstant *x-imagetext16*                  77)  
-(defconstant *x-createcolormap*               78)    
-(defconstant *x-freecolormap*                 79) 
-(defconstant *x-copycolormapandfree*          80)       
-(defconstant *x-installcolormap*              81)  
-(defconstant *x-uninstallcolormap*            82)   
-(defconstant *x-listinstalledcolormaps*       83)       
-(defconstant *x-alloccolor*                   84)
-(defconstant *x-allocnamedcolor*              85)    
-(defconstant *x-alloccolorcells*              86)   
-(defconstant *x-alloccolorplanes*             87)   
-(defconstant *x-freecolors*                   88)
-(defconstant *x-storecolors*                  89)
-(defconstant *x-storenamedcolor*              90)   
-(defconstant *x-querycolors*                  91)
-(defconstant *x-lookupcolor*                  92)
-(defconstant *x-createcursor*                 93)
-(defconstant *x-createglyphcursor*            94)    
-(defconstant *x-freecursor*                   95)
-(defconstant *x-recolorcursor*                96)  
-(defconstant *x-querybestsize*                97) 
-(defconstant *x-queryextension*               98) 
-(defconstant *x-listextensions*               99)
-(defconstant *x-setkeyboardmapping*           100)
-(defconstant *x-getkeyboardmapping*           101)
-(defconstant *x-changekeyboardcontrol*        102)               
-(defconstant *x-getkeyboardcontrol*           103)           
-(defconstant *x-bell*                         104)
-(defconstant *x-changepointercontrol*         105)
-(defconstant *x-getpointercontrol*            106)
-(defconstant *x-setscreensaver*               107)         
-(defconstant *x-getscreensaver*               108)        
-(defconstant *x-changehosts*                  109)    
-(defconstant *x-listhosts*                    110) 
-(defconstant *x-changeaccesscontrol*          111)          
-(defconstant *x-changeclosedownmode*          112)
-(defconstant *x-killclient*                   113)
-(defconstant *x-rotateproperties*	      114)
-(defconstant *x-forcescreensaver*	      115)
-(defconstant *x-setpointermapping*            116)
-(defconstant *x-getpointermapping*            117)
-(defconstant *x-setmodifiermapping*	      118)
-(defconstant *x-getmodifiermapping*	      119)
-(defconstant *x-nooperation*                  127)
+(defconstant +x-createwindow+                  1)
+(defconstant +x-changewindowattributes+        2)
+(defconstant +x-getwindowattributes+           3)
+(defconstant +x-destroywindow+                 4)
+(defconstant +x-destroysubwindows+             5)
+(defconstant +x-changesaveset+                 6)
+(defconstant +x-reparentwindow+                7)
+(defconstant +x-mapwindow+                     8)
+(defconstant +x-mapsubwindows+                 9)
+(defconstant +x-unmapwindow+                  10)
+(defconstant +x-unmapsubwindows+              11)
+(defconstant +x-configurewindow+              12)
+(defconstant +x-circulatewindow+              13)
+(defconstant +x-getgeometry+                  14)
+(defconstant +x-querytree+                    15)
+(defconstant +x-internatom+                   16)
+(defconstant +x-getatomname+                  17)
+(defconstant +x-changeproperty+               18)
+(defconstant +x-deleteproperty+               19)
+(defconstant +x-getproperty+                  20)
+(defconstant +x-listproperties+               21)
+(defconstant +x-setselectionowner+            22)
+(defconstant +x-getselectionowner+            23)
+(defconstant +x-convertselection+             24)
+(defconstant +x-sendevent+                    25)
+(defconstant +x-grabpointer+                  26)
+(defconstant +x-ungrabpointer+                27)
+(defconstant +x-grabbutton+                   28)
+(defconstant +x-ungrabbutton+                 29)
+(defconstant +x-changeactivepointergrab+      30)
+(defconstant +x-grabkeyboard+                 31)
+(defconstant +x-ungrabkeyboard+               32)
+(defconstant +x-grabkey+                      33)
+(defconstant +x-ungrabkey+                    34)
+(defconstant +x-allowevents+                  35)
+(defconstant +x-grabserver+                   36)
+(defconstant +x-ungrabserver+                 37)
+(defconstant +x-querypointer+                 38)
+(defconstant +x-getmotionevents+              39)
+(defconstant +x-translatecoords+              40)
+(defconstant +x-warppointer+                  41)
+(defconstant +x-setinputfocus+                42)
+(defconstant +x-getinputfocus+                43)
+(defconstant +x-querykeymap+                  44)
+(defconstant +x-openfont+                     45)
+(defconstant +x-closefont+                    46)
+(defconstant +x-queryfont+                    47)
+(defconstant +x-querytextextents+             48)
+(defconstant +x-listfonts+                    49)
+(defconstant +x-listfontswithinfo+    	      50)
+(defconstant +x-setfontpath+                  51)
+(defconstant +x-getfontpath+                  52)
+(defconstant +x-createpixmap+                 53)
+(defconstant +x-freepixmap+                   54)
+(defconstant +x-creategc+                     55)
+(defconstant +x-changegc+                     56)
+(defconstant +x-copygc+                       57)
+(defconstant +x-setdashes+                    58)
+(defconstant +x-setcliprectangles+            59)
+(defconstant +x-freegc+                       60)
+(defconstant +x-cleartobackground+            61)
+(defconstant +x-copyarea+                     62)
+(defconstant +x-copyplane+                    63)
+(defconstant +x-polypoint+                    64)
+(defconstant +x-polyline+                     65)
+(defconstant +x-polysegment+                  66)
+(defconstant +x-polyrectangle+                67)
+(defconstant +x-polyarc+                      68)
+(defconstant +x-fillpoly+                     69)
+(defconstant +x-polyfillrectangle+            70)
+(defconstant +x-polyfillarc+                  71)
+(defconstant +x-putimage+                     72)
+(defconstant +x-getimage+                     73)
+(defconstant +x-polytext8+                    74)
+(defconstant +x-polytext16+                   75)
+(defconstant +x-imagetext8+                   76)
+(defconstant +x-imagetext16+                  77)
+(defconstant +x-createcolormap+               78)
+(defconstant +x-freecolormap+                 79)
+(defconstant +x-copycolormapandfree+          80)
+(defconstant +x-installcolormap+              81)
+(defconstant +x-uninstallcolormap+            82)
+(defconstant +x-listinstalledcolormaps+       83)
+(defconstant +x-alloccolor+                   84)
+(defconstant +x-allocnamedcolor+              85)
+(defconstant +x-alloccolorcells+              86)
+(defconstant +x-alloccolorplanes+             87)
+(defconstant +x-freecolors+                   88)
+(defconstant +x-storecolors+                  89)
+(defconstant +x-storenamedcolor+              90)
+(defconstant +x-querycolors+                  91)
+(defconstant +x-lookupcolor+                  92)
+(defconstant +x-createcursor+                 93)
+(defconstant +x-createglyphcursor+            94)
+(defconstant +x-freecursor+                   95)
+(defconstant +x-recolorcursor+                96)
+(defconstant +x-querybestsize+                97)
+(defconstant +x-queryextension+               98)
+(defconstant +x-listextensions+               99)
+(defconstant +x-setkeyboardmapping+           100)
+(defconstant +x-getkeyboardmapping+           101)
+(defconstant +x-changekeyboardcontrol+        102)
+(defconstant +x-getkeyboardcontrol+           103)
+(defconstant +x-bell+                         104)
+(defconstant +x-changepointercontrol+         105)
+(defconstant +x-getpointercontrol+            106)
+(defconstant +x-setscreensaver+               107)
+(defconstant +x-getscreensaver+               108)
+(defconstant +x-changehosts+                  109)
+(defconstant +x-listhosts+                    110)
+(defconstant +x-changeaccesscontrol+          111)
+(defconstant +x-changeclosedownmode+          112)
+(defconstant +x-killclient+                   113)
+(defconstant +x-rotateproperties+	      114)
+(defconstant +x-forcescreensaver+	      115)
+(defconstant +x-setpointermapping+            116)
+(defconstant +x-getpointermapping+            117)
+(defconstant +x-setmodifiermapping+	      118)
+(defconstant +x-getmodifiermapping+	      119)
+(defconstant +x-nooperation+                  127)
 
 ;;; Some macros for threaded lists
 
@@ -957,6 +945,7 @@
        (loop
 	 (let ((,y ,list))
 	   (declare (type (or null ,type) ,y)
+                    #-clx-debugging
 		    (optimize (speed 3) (safety 0)))
 	   (setf (,next ,x) ,y)
 	   (when (conditional-store ,list ,y ,x)
@@ -967,6 +956,7 @@
     `(loop
        (let ((,y ,list))
 	 (declare (type (or null ,type) ,y)
+                  #-clx-debugging
 		  (optimize (speed 3) (safety 0)))
 	 (if (null ,y)
 	     (return nil)
@@ -983,6 +973,7 @@
 	   (,first ,list))
        (declare (type ,type ,z)
 		(type (or null ,type) ,first)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (if (null ,first)
 	   (setf ,list ,z)
@@ -998,6 +989,7 @@
   (let ((x (gensym)))
     `(let ((,x ,item))
        (declare (type ,type ,x)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (shiftf (,next ,x) ,list ,x)
        ,x)))
@@ -1006,6 +998,7 @@
   (let ((x (gensym)))
     `(let ((,x ,list))
        (declare (type (or null ,type) ,x)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (when ,x
 	 (shiftf ,list (,next (the ,type ,x)) nil))
@@ -1015,6 +1008,7 @@
   (let ((x (gensym)))
     `(let ((,x ,item))
        (declare (type ,type ,x)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (if (null ,tail)
 	   (threaded-nconc ,x ,head ,next ,type)
@@ -1025,6 +1019,7 @@
   (let ((x (gensym)))
     `(let ((,x ,head))
        (declare (type (or null ,type) ,x)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (when ,x
 	 (when (eq ,x ,tail)
@@ -1036,6 +1031,7 @@
   (let ((x (gensym)))
     `(let ((,x ,item))
        (declare (type ,type ,x)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (if (null ,tail)
 	   (setf ,tail (setf ,head ,x))
@@ -1058,6 +1054,7 @@
 	   (,first ,list))
        (declare (type ,type ,x)
 		(type (or null ,type) ,first)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0)))
        (when ,first
 	 (if (eq ,first ,x)
@@ -1081,5 +1078,6 @@
 	  ,count)
        (declare (type (or null ,type) ,x)
 		(type array-index ,count)
+                #-clx-debugging
 		(optimize (speed 3) (safety 0))))))
 
