@@ -2,7 +2,7 @@
  * Module for Raw Sockets / CLISP
  * Fred Cohen, 2003-2004
  * Don Cohen, 2003-2004
- * Sam Steingold 2004-2006
+ * Sam Steingold 2004-2007
  * Bruno Haible 2004-2005
  * <http://www.opengroup.org/onlinepubs/007908799/xns/syssocket.h.html>
  */
@@ -93,16 +93,6 @@
 # include <ifaddrs.h>
 #endif
 typedef SOCKET rawsock_t;
-#if SIZEOF_SIZE_T == 8
-# define size_to_I  uint64_to_I
-#else
-# define size_to_I  uint32_to_I
-#endif
-#if SIZEOF_SSIZE_T == 8
-# define ssize_to_I  sint64_to_I
-#else
-# define ssize_to_I  sint32_to_I
-#endif
 
 DEFMODULE(rawsock,"RAWSOCK")
 
@@ -142,15 +132,16 @@ static void* parse_buffer_arg (gcv_object_t *arg_, size_t *size, int prot) {
  > prot: PROT_READ or PROT_READ_WRITE
  < returns the address of the data area
  can trigger GC */
-static void* check_struct_data (object type, object arg, SOCKLEN_T *size,
-                                int prot) {
-  object vec = TheStructure(check_classname(arg,type))->recdata[1];
+static void* check_struct_data (object type, gcv_object_t *arg,
+                                CLISP_SOCKLEN_T *size, int prot) {
+  object vec = TheStructure(*arg = check_classname(*arg,type))->recdata[1];
   *size = Sbvector_length(vec);
   { void *start_address = (void*)(TheSbvector(vec)->data);
     handle_fault_range(prot,(aint)start_address,(aint)start_address + *size);
     return start_address;
   }
 }
+#define CHECK_SOCKADDR(a,s,p) (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,a,s,p)
 
 /* check that the arg is a vector of byte vectors
  > *arg_: vector
@@ -217,11 +208,9 @@ static void fill_iovec (object vect, size_t offset, ssize_t veclen,
 }
 
 DEFUN(RAWSOCK:SOCKADDR-FAMILY, sa) {
-  SOCKLEN_T size;
-  struct sockaddr *sa =
-    (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,popSTACK(),&size,
-                                        PROT_READ);
-  VALUES2(fixnum(sa->sa_family),fixnum(size));
+  CLISP_SOCKLEN_T size;
+  struct sockaddr *sa = CHECK_SOCKADDR(&STACK_0,&size,PROT_READ);
+  VALUES2(fixnum(sa->sa_family),fixnum(size)); skipSTACK(1);
 }
 DEFUN(RAWSOCK::SOCKADDR-SLOT,&optional slot) {
   /* return offset & size of the slo in SOCKADDR */
@@ -305,9 +294,19 @@ DEFUN(RAWSOCK:MAKE-SOCKADDR,family &optional data) {
   skipSTACK(2);
 }
 
+/* ================== SIGPIPE handling ================== */
+#if defined(HAVE_SIGNALS)
+extern bool writing_to_subprocess;
+# define begin_sock_call()  writing_to_subprocess=true;  begin_system_call()
+# define end_sock_call()    writing_to_subprocess=false; end_system_call()
+#else
+# define begin_sock_call()  begin_system_call()
+# define end_sock_call()    end_system_call()
+#endif
+
 /* invoke system call C, place return value in R, report error on socket S */
 #define SYSCALL(r,s,c)                                  \
-  do { begin_system_call(); r = c; end_system_call();   \
+  do { begin_sock_call(); r = c; end_sock_call();       \
     if (r == -1) {                                      \
       if (s<=0) OS_error();                             \
       else OS_file_error(fixnum(s));                    \
@@ -424,12 +423,7 @@ DEFUN(RAWSOCK:CONVERT-ADDRESS, family address) {
 /* return RAWSOCK:PROTOCOL object in value1 */
 static Values protoent_to_protocol (struct protoent *pe) {
   pushSTACK(asciz_to_string(pe->p_name,GLO(misc_encoding)));
-  { int count = 0;
-    char **alias = pe->p_aliases;
-    for (; *alias; count++, alias++)
-      pushSTACK(asciz_to_string(*alias,GLO(misc_encoding)));
-    value1 = listof(count); pushSTACK(value1);
-  }
+  push_string_array(pe->p_aliases);
   pushSTACK(sint_to_I(pe->p_proto));
   funcall(`RAWSOCK::MAKE-PROTOCOL`,3);
 }
@@ -475,12 +469,7 @@ DEFUN(RAWSOCK:PROTOCOL, &optional protocol)
 /* return RAWSOCK:NETWORK object in value1 */
 static Values netent_to_network (struct netent *ne) {
   pushSTACK(asciz_to_string(ne->n_name,GLO(misc_encoding)));
-  { int count = 0;
-    char **alias = ne->n_aliases;
-    for (; *alias; count++, alias++)
-      pushSTACK(asciz_to_string(*alias,GLO(misc_encoding)));
-    value1 = listof(count); pushSTACK(value1);
-  }
+  push_string_array(ne->n_aliases);
   pushSTACK(sint_to_I(ne->n_addrtype));
   pushSTACK(sint_to_I(ne->n_net));
   funcall(`RAWSOCK::MAKE-NETWORK`,4);
@@ -674,7 +663,7 @@ DEFUN(RAWSOCK:SOCKETPAIR,domain type protocol) {
   SYSCALL(retval,-1,socketpair(domain,type,protocol,sock));
 #else /* woe32 et al */
   struct sockaddr_in addr;
-  SOCKLEN_T sa_size = sizeof(struct sockaddr_in);
+  CLISP_SOCKLEN_T sa_size = sizeof(struct sockaddr_in);
   rawsock_t newsock;
   addr.sin_family = domain;
   addr.sin_port = 0;            /* OS will assign an available port */
@@ -711,12 +700,11 @@ DEFUN(RAWSOCK:SOCKATMARK, sock) {
  DANGER: the return value is invalidated by GC!
  can trigger GC */
 static void optional_sockaddr_argument (gcv_object_t *arg, struct sockaddr**sa,
-                                        SOCKLEN_T *size) {
+                                        CLISP_SOCKLEN_T *size) {
   if (nullp(*arg)) *sa = NULL;
   else {
     if (eq(T,*arg)) *arg = make_sockaddr();
-    *sa = (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,*arg,size,
-                                              PROT_READ_WRITE);
+    *sa = CHECK_SOCKADDR(arg,size,PROT_READ_WRITE);
   }
 }
 
@@ -724,7 +712,7 @@ DEFUN(RAWSOCK:ACCEPT,socket sockaddr) {
   rawsock_t sock = I_to_uint(check_uint(STACK_1));
   int retval;
   struct sockaddr *sa = NULL;
-  SOCKLEN_T sa_size;
+  CLISP_SOCKLEN_T sa_size;
   optional_sockaddr_argument(&STACK_0,&sa,&sa_size);
   /* no GC after this point! */
   SYSCALL(retval,sock,accept(sock,sa,&sa_size));
@@ -734,10 +722,8 @@ DEFUN(RAWSOCK:ACCEPT,socket sockaddr) {
 DEFUN(RAWSOCK:BIND,socket sockaddr) {
   rawsock_t sock = I_to_uint(check_uint(STACK_1));
   int retval;
-  SOCKLEN_T size;
-  struct sockaddr *sa =
-    (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,STACK_0,&size,
-                                        PROT_READ);
+  CLISP_SOCKLEN_T size;
+  struct sockaddr *sa = CHECK_SOCKADDR(&STACK_0,&size,PROT_READ);
   /* no GC after this point! */
   SYSCALL(retval,sock,bind(sock,sa,size));
   VALUES0; skipSTACK(2);
@@ -746,10 +732,8 @@ DEFUN(RAWSOCK:BIND,socket sockaddr) {
 DEFUN(RAWSOCK:CONNECT,socket sockaddr) {
   rawsock_t sock = I_to_uint(check_uint(STACK_1));
   int retval;
-  SOCKLEN_T size;
-  struct sockaddr *sa =
-    (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,STACK_0,&size,
-                                        PROT_READ);
+  CLISP_SOCKLEN_T size;
+  struct sockaddr *sa = CHECK_SOCKADDR(&STACK_0,&size,PROT_READ);
   /* no GC after this point! */
   SYSCALL(retval,sock,connect(sock,sa,size));
   VALUES0; skipSTACK(2);
@@ -759,7 +743,7 @@ DEFUN(RAWSOCK:GETPEERNAME,socket sockaddr) {
   rawsock_t sock = I_to_uint(check_uint(STACK_1));
   int retval;
   struct sockaddr *sa = NULL;
-  SOCKLEN_T sa_size;
+  CLISP_SOCKLEN_T sa_size;
   optional_sockaddr_argument(&STACK_0,&sa,&sa_size);
   /* no GC after this point! */
   SYSCALL(retval,sock,getpeername(sock,sa,&sa_size));
@@ -770,7 +754,7 @@ DEFUN(RAWSOCK:GETSOCKNAME,socket sockaddr) {
   rawsock_t sock = I_to_uint(check_uint(STACK_1));
   int retval;
   struct sockaddr *sa = NULL;
-  SOCKLEN_T sa_size;
+  CLISP_SOCKLEN_T sa_size;
   optional_sockaddr_argument(&STACK_0,&sa,&sa_size);
   /* no GC after this point! */
   SYSCALL(retval,sock,getsockname(sock,sa,&sa_size));
@@ -838,17 +822,15 @@ DEFFLAGSET(getnameinfo_flags, NI_NOFQDN NI_NUMERICHOST NI_NAMEREQD \
 DEFUN(RAWSOCK:GETNAMEINFO, sockaddr &key NOFQDN NUMERICHOST NAMEREQD \
       NUMERICSERV NUMERICSCOPE DGRAM) {
   int flags = getnameinfo_flags();
-  SOCKLEN_T size;
-  struct sockaddr *sa =
-    (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,popSTACK(),&size,
-                                        PROT_READ);
+  CLISP_SOCKLEN_T size;
+  struct sockaddr *sa = CHECK_SOCKADDR(&STACK_0,&size,PROT_READ);
   char node[BUFSIZ], service[BUFSIZ];
   int status;
   begin_system_call();
   if ((status = getnameinfo_f(sa,size,node,BUFSIZ,service,BUFSIZ,flags)))
     error_eai(status);
   end_system_call();
-  pushSTACK(asciz_to_string(service,GLO(misc_encoding)));
+  STACK_0 = asciz_to_string(service,GLO(misc_encoding)); /* forget sockaddr */
   VALUES2(asciz_to_string(node,GLO(misc_encoding)),popSTACK());
 }
 #endif
@@ -913,8 +895,7 @@ DEFUN(RAWSOCK:GETADDRINFO, &key NODE SERVICE PROTOCOL SOCKTYPE FAMILY \
     pushSTACK(check_socket_type_reverse(tmp->ai_socktype));
     pushSTACK(check_socket_protocol_reverse(tmp->ai_protocol));
     pushSTACK(sockaddr_to_lisp(tmp->ai_addr,tmp->ai_addrlen));
-    pushSTACK(tmp->ai_canonname == NULL ? NIL
-              : asciz_to_string(tmp->ai_canonname,GLO(misc_encoding)));
+    pushSTACK(safe_to_string(tmp->ai_canonname));
     funcall(`RAWSOCK::MAKE-ADDRINFO`,6); pushSTACK(value1);
   }
   if (ret) { begin_system_call(); freeaddrinfo_f(ret); end_system_call(); }
@@ -950,7 +931,7 @@ DEFUN(RAWSOCK:RECVFROM, socket buffer address &key START END PEEK OOB WAITALL) {
   struct sockaddr *sa = NULL;
   void *buffer;
   size_t buffer_len;
-  SOCKLEN_T sa_size;
+  CLISP_SOCKLEN_T sa_size;
   if (!missingp(STACK_0)) STACK_0 = check_posfixnum(STACK_0);
   if (!missingp(STACK_1)) STACK_1 = check_posfixnum(STACK_1);
   STACK_3 = check_byte_vector(STACK_3);
@@ -1003,10 +984,9 @@ static void fill_msghdr (gcv_object_t *mho, uintL offset, struct msghdr *mhp,
                      (aint)mhp->msg_control + mhp->msg_controllen);
   fill_iovec(TheStructure(*mho)->recdata[MSG_IOVEC],offset,mhp->msg_iovlen,
              mhp->msg_iov,prot);
-  mhp->msg_name = (struct sockaddr*)
-    check_struct_data(`RAWSOCK::SOCKADDR`,
-                      TheStructure(*mho)->recdata[MSG_SOCKADDR],
-                      &(mhp->msg_namelen),prot);
+  pushSTACK(TheStructure(*mho)->recdata[MSG_SOCKADDR]);
+  mhp->msg_name = CHECK_SOCKADDR(&STACK_0,&(mhp->msg_namelen),prot);
+  TheStructure(*mho)->recdata[MSG_SOCKADDR] = popSTACK();
 }
 /* POSIX recvmsg() */
 DEFUN(RAWSOCK:RECVMSG,socket message &key START END PEEK OOB WAITALL) {
@@ -1085,12 +1065,11 @@ DEFUN(RAWSOCK:SENDTO, socket buffer address &key START END OOB EOR) {
   struct sockaddr *sa;
   void *buffer;
   size_t buffer_len;
-  SOCKLEN_T size;
+  CLISP_SOCKLEN_T size;
   if (!missingp(STACK_0)) STACK_0 = check_posfixnum(STACK_0);
   if (!missingp(STACK_1)) STACK_1 = check_posfixnum(STACK_1);
   STACK_3 = check_byte_vector(STACK_3);
-  sa = (struct sockaddr*)check_struct_data(`RAWSOCK::SOCKADDR`,STACK_2,&size,
-                                           PROT_READ);
+  sa = CHECK_SOCKADDR(&STACK_2,&size,PROT_READ);
   /* no GC after this point! - buffer, start, end have been checked already */
   buffer = parse_buffer_arg(&STACK_3,&buffer_len,PROT_READ);
   SYSCALL(retval,sock,sendto(sock,(const BUF_TYPE_T)buffer,
@@ -1186,11 +1165,11 @@ DEFCHECKER(sockopt_name,default=-1,prefix=SO,                            \
 #if defined(HAVE_GETSOCKOPT) || defined(WIN32_NATIVE)
 #define GET_SOCK_OPT(opt_type,retform) do {                             \
     opt_type val;                                                       \
-    SOCKLEN_T len = sizeof(val);                                        \
+    CLISP_SOCKLEN_T len = sizeof(val);                                  \
     int status;                                                         \
-    begin_system_call();                                                \
+    begin_sock_call();                                                  \
     status = getsockopt(sock,level,name,(SETSOCKOPT_ARG_T)&val,&len);   \
-    end_system_call();                                                  \
+    end_sock_call();                                                    \
     if (status==0) return retform;                                      \
     else return (err_p ? OS_file_error(fixnum(sock)),NIL : S(Kerror));  \
   } while(0)
@@ -1301,9 +1280,9 @@ DEFUN(RAWSOCK:SOCKET-OPTION, sock name &key :LEVEL)
 #define SET_SOCK_OPT(opt_type,valform) do {                             \
     int status;                                                         \
     opt_type val; valform;                                              \
-    begin_system_call();                                                \
+    begin_sock_call();                                                  \
     status = setsockopt(sock,level,name,(SETSOCKOPT_ARG_T)&val,sizeof(val)); \
-    end_system_call();                                                  \
+    end_sock_call();                                                    \
     if (status) OS_file_error(fixnum(sock));                            \
     return;                                                             \
   } while(0)
