@@ -1,5 +1,5 @@
 ;;; handle the posix functions
-;;; Sam Steingold 1999-2005
+;;; Sam Steingold 1999-2007
 
 (defpackage #:posix
   (:use #:common-lisp #:ext)
@@ -7,19 +7,19 @@
   (:import-from "SYS" sys::process-id)
   (:shadowing-import-from "EXPORTING" #:defstruct)
   (:export
-   #:resolve-host-ipaddr #:bogomips #:mkstemp #:mkdtemp
+   #:resolve-host-ipaddr #:bogomips #:loadavg #:mkstemp #:mkdtemp
    #:stream-lock #:with-stream-lock #:duplicate-handle #:copy-file
    #:file-owner #:physical-memory #:stream-options #+unix #:string-time
    #+(or :win32 :cygwin) #:file-properties #+unix #:make-xterm-io-stream
    #:priority #:process-id #:openlog #:setlogmask #:syslog #:closelog
    #:getpgid #:setpgrp #:getsid #:setsid #:setpgid #:kill #:sync
-   #:erf #:erfc #:j0 #:j1 #:jn #:y0 #:y1 #:yn #:gamma #:lgamma))
+   #:erf #:erfc #:j0 #:j1 #:jn #:y0 #:y1 #:yn #:gamma #:lgamma #:ffs))
 
 (pushnew :syscalls *features*)
+(provide "syscalls")
 (in-package #:posix)
 
 (setf (documentation (find-package '#:posix) 'sys::impnotes) "syscalls")
-(setf (documentation 'sys::process-id 'sys::impnotes) "process-id")
 
 ;;; ============================================================
 #+unix (progn
@@ -126,7 +126,7 @@
   (vol-name nil :type (or null string) :read-only t)
   (fs-type nil :type (or null string) :read-only t))
 ;;; ============================================================
-#+unix (export '(sysconf confstr))
+#+unix (export '(sysconf confstr pathconf))
 #+unix
 (defstruct (uname (:constructor make-uname (sysname nodename release
                                             version machine)))
@@ -355,29 +355,43 @@
 
 ;;;--------------------------------------------------------------------------
 #+unix
-(defun make-xterm-io-stream ()
+(defun make-xterm-io-stream (&key (title "CLISP I/O"))
   (let* ((tmps (mkstemp "/tmp/clisp-x-io-XXXXXX"))
-         (file (namestring tmps))
-         (title "CLISP I/O")
+         (pipe (namestring tmps))
          xio
          (clos::*warn-if-gf-already-called* nil))
     (close tmps) (delete-file tmps)
     (mknod tmps :FIFO :RWXU)
+    (setq title (string title))
+    ;; - tty tells us what device to use for IO
+    ;; - cat holds xterm from quitting and prints the good-bye message
+    ;;   (actually, the xterm window disappears before you can read it...)
     (shell (format nil "xterm -n ~s -T ~s -e 'tty >> ~a; cat ~a' &"
-                   title title file file))
-    (setq xio (open file :direction :io))
-    ;; we cannot rely on GC closing files because we also need to remove
-    ;; the FIFO which is done by the :AFTER method below
+                   title title pipe pipe))
+    (with-open-file (s pipe :direction :input)
+      (setq xio (open (read-line s) :direction :io)))
+    ;; GC uses the internal non-generic builtin_stream_close() so
+    ;; we cannot rely on GC closing files because we also need to
+    ;;  - write something into the pipe to terminate cat and thus xterm and
+    ;;  - remove the pipe
+    ;; which is done by the :AFTER method below
     (ext:finalize xio #'close)
     (defmethod close :after ((x (eql xio)) &rest junk)
       (declare (ignore x junk))
-      (with-open-file (s file :direction :output)
+      (with-open-file (s pipe :direction :output)
         (write-line (SYS::TEXT "Bye.") s))
-      (delete-file file)
+      (delete-file pipe)
       (let ((clos::*warn-if-gf-already-called* nil))
         (remove-method #'close (find-method #'close '(:after) `((eql ,xio))))))
     xio))
 
+;;;--------------------------------------------------------------------------
+(defun ffs (n) (integer-length (logand n (- n))))
+;; http://www.opengroup.org/onlinepubs/009695399/functions/ffs.html
+;; this lisp implementation is about 10% faster than using FFI:
+;; (ffi:def-call-out ffs (:name "ffs") (:arguments (i ffi:int))
+;;   (:return-type ffi:int) (:language :stdc) (:library :default))
+;; and it also supports bignums.
 ;;;--------------------------------------------------------------------------
 (setf (package-lock "EXT") nil)
 (use-package '("POSIX") "EXT")
