@@ -2,7 +2,7 @@
 ;; ----------------------------------------------------------------------------
 (defmacro typecase (&whole whole-form
                     keyform &rest typeclauselist)
-  (let* ((tempvar (gensym))
+  (let* ((tempvar (gensym "TYPECASE-KEY-"))
          (condclauselist nil))
     (do ((typeclauselistr typeclauselist (cdr typeclauselistr)) spec)
         ((atom typeclauselistr))
@@ -35,8 +35,8 @@
 (defun prompt-for-new-value-string () ; ABI
   (concatenate 'string "~&" (TEXT "New ~S: ")))
 (predefmacro check-type (place typespec &optional (string nil))
-  (let ((tag1 (gensym))
-        (tag2 (gensym)))
+  (let ((tag1 (gensym "CHECK-TYPE-"))
+        (tag2 (gensym "OK-")))
     `(TAGBODY
        ,tag1
        (WHEN (TYPEP ,place ',typespec) (GO ,tag2))
@@ -58,8 +58,8 @@
     (TEXT "~S must evaluate to a non-NIL value.")
     test-form))
 (predefmacro assert (test-form &optional (place-list nil) (string nil) &rest args)
-  (let ((tag1 (gensym))
-        (tag2 (gensym)))
+  (let ((tag1 (gensym "ASSERT-"))
+        (tag2 (gensym "OK-")))
     `(TAGBODY
        ,tag1
        (WHEN ,test-form (GO ,tag2))
@@ -184,7 +184,7 @@
   (multiple-value-bind (body-rest declarations docstring)
       (SYSTEM::PARSE-BODY body t)
     (if declarations (setq declarations (list (cons 'DECLARE declarations))))
-    (let ((%whole-form whole-form)
+    (let ((%whole-form whole-form) (%proper-list-p t)
           (%arg-count 0) (%min-args 0) (%restp nil) (%null-tests nil)
           (%let-list nil) (%keyword-tests nil) (%default-form '(QUOTE *)))
       (analyze1 lambdalist '(CDR <DEFTYPE-FORM>) name '<DEFTYPE-FORM>)
@@ -222,16 +222,11 @@
       'define-symbol-macro symbol))
   `(LET ()
      (EVAL-WHEN (COMPILE LOAD EVAL)
-       (CHECK-NOT-SPECIAL-VARIABLE-P ',symbol)
+       (SYSTEM::%PROCLAIM-SYMBOL-MACRO ',symbol)
        (SYSTEM::%PUT ',symbol 'SYSTEM::SYMBOLMACRO
-                     (SYSTEM::MAKE-GLOBAL-SYMBOL-MACRO ',expansion))
-       (SYSTEM::%PROCLAIM-SYMBOL-MACRO ',symbol))
+                     (SYSTEM::MAKE-GLOBAL-SYMBOL-MACRO ',expansion)))
      ',symbol))
-(defun check-not-special-variable-p (symbol) ; ABI
-  (when (special-variable-p symbol)
-    (error-of-type 'program-error
-      (TEXT "~S: the symbol ~S names a global variable")
-      'define-symbol-macro symbol)))
+(defun check-not-special-variable-p (symbol)) ; legacy ABI
 ;; ----------------------------------------------------------------------------
 ;; X3J13 vote <123>
 ;; Macro (nth-value n form) == (nth n (multiple-value-list form)), CLtL2 S. 184
@@ -240,12 +235,12 @@
     (if (< n (1- multiple-values-limit))
       (if (= n 0)
         `(PROG1 ,form)
-        (let* ((resultvar (gensym))
+        (let* ((resultvar (gensym "RESULT-"))
                (vars (list resultvar))
                (ignores '()))
           (do ((i n (1- i)))
               ((zerop i))
-            (let ((g (gensym)))
+            (let ((g (gensym "IG")))
               (setq vars (cons g vars))
               (setq ignores (cons g ignores))
           ) )
@@ -270,10 +265,10 @@
       (UNWIND-PROTECT ,form (MULTIPLE-VALUE-CALL #'%TIME (%%TIME) ,@vars)))))
 ;; ----------------------------------------------------------------------------
 (defmacro times (form)
-  (let ((var1 (gensym))
-        (var2 (gensym))
-        (var3 (gensym))
-        (var4 (gensym))
+  (let ((var1 (gensym "HEAP1-"))
+        (var2 (gensym "GC-STAT1-"))
+        (var3 (gensym "VALUES-"))
+        (var4 (gensym "GC-STAT2-"))
         (timevars1 (gensym-list 9))
         (timevars2 (gensym-list 9)))
     (setq form
@@ -330,7 +325,7 @@
                                  &body body)
   (multiple-value-bind (body-rest declarations) (SYSTEM::PARSE-BODY body)
     (if string
-      (let ((ignored-var (gensym)))
+      (let ((ignored-var (gensym "IG")))
         `(LET ((,var (SYS::MAKE-STRING-PUSH-STREAM ,string))
                (,ignored-var ,element-type))
            (DECLARE (READ-ONLY ,var) (IGNORE ,ignored-var) ,@declarations)
